<?php
// $Id: main.php,v 1.1 2004/07/11 10:28:56 Farsus Exp $
// -------------------------------------------------------------------------//
//			       RUNCMS                                                   //
//                                                                          //
//	 reliable - Unique - Nocost &  Simplicity & ease off use                //
//                       < http://www.runcms.org >                          //
// -------------------------------------------------------------------------//
// Original Author: Kazumi Ono
// Author Website : http://www.mywebaddons.com/ , http://www.myweb.ne.jp
// License Type   : GPL: See /manual/LICENSES/GPL.txt
// ------------------------------------------------------------------------- //

if ( !preg_match("/admin\.php/i", _PHP_SELF) ) {
	exit();
	}

include_once(XOOPS_ROOT_PATH."/modules/system/admin/smilies/smilies.php");

switch($op) {

	case "SmilesAdmin":
		SmilesAdmin();
		break;

	case "SmilesAdd":
		SmilesAdd($code,$smile_url,$emotion);
		break;

	case "SmilesEdit":
		SmilesEdit($id);
		break;

	case "SmilesSave":
		SmilesSave($id,$code,$smile_url,$emotion);
		break;

	case "SmilesDel":
		SmilesDel($id, $ok);
		break;

	default:
		SmilesAdmin();
		break;
}

?>
